# MARKIT Gateway

This repo contains code to interact with [rfmarkit-esp-node](https://github.com/mvig-robotflow/rfmarkit-esp-node).

## Get Started

```shell
git clone https://github.com/mvig-robotflow/rfmarkit-gateway.git
python setup.py install
```

Or from PYPI:

```shell
python -m pip install markit-gateway
```

## Documentation

For documentation, please refer to [rfmarkit-gateway/docs](https://github.com/mvig-robotflow/rfmarkit-gateway/docs).
